pub struct GlobalOpts {
pub log: Option<PathBuf>,
pub debug: bool,
pub log_format: Option<String>,
pub root: Option<PathBuf>,
pub systemd_cgroup: bool,
}Fields
log: Option<PathBuf>set the log file to write youki logs to (default is ‘/dev/stderr’)
debug: boolchange log level to debug, but the log-level flag takes precedence
log_format: Option<String>set the log format (‘text’ (default), or ‘json’) (default: “text”)
root: Option<PathBuf>root directory to store container state
systemd_cgroup: boolEnable systemd cgroup manager, rather then use the cgroupfs directly.