pub struct Run {
pub bundle: PathBuf,
pub console_socket: Option<PathBuf>,
pub pid_file: Option<PathBuf>,
pub no_subreaper: bool,
pub no_pivot: bool,
pub no_new_keyring: bool,
pub preserve_fds: i32,
pub keep: bool,
pub container_id: String,
pub detach: bool,
}Expand description
Create a container and immediately start it
Fields
bundle: PathBufPath to the bundle directory, containing config.json and root filesystem
console_socket: Option<PathBuf>Unix socket (file) path , which will receive file descriptor of the writing end of the pseudoterminal
pid_file: Option<PathBuf>File to write pid of the container created
no_subreaper: boolDisable the use of the subreaper used to reap reparented processes
no_pivot: boolDo not use pivot root to jail process inside rootfs
no_new_keyring: boolDo not create a new session keyring for the container. This will cause the container to inherit the calling processes session key.
preserve_fds: i32Pass N additional file descriptors to the container (stdio + $LISTEN_FDS + N in total)
keep: boolcontainer_id: Stringname of the container instance to be started
detach: boolDetach from the container process